@@ -31,6 +31,7 @@ class S3:
 			root = ''
 		self._root = root
 		self._spark = spark
+		self._file_system = S3FileSystem(key=key, secret=secret, use_ssl=False)
 
 	@property
 	def root(self):
@@ -38,7 +39,7 @@ class S3:
 
 	@property
 	def file_system(self):
-		return S3FileSystem(key=self._key, secret=self._secret, use_ssl=False)
+		return self._file_system
 
 	def _get_absolute_path(self, path):
 		if not path.startswith(self._root):
@@ -232,7 +233,7 @@ class S3:
 		if mode == 'overwrite' and self.exists(path=path):
 			self.rm(path=path, recursive=True)
 
-		data.write.mode(mode).save(path=path)
+		data.write.mode(mode).parquet(path=path)
 		return self.ls(path=path)
 
 	@property
